import { QuetzFrontEndPlugin } from '@quetz-frontend/application';
export declare namespace CommandIDs {
    const open = "@quetz-frontend/home-extension:open";
}
declare const plugin: QuetzFrontEndPlugin<void>;
export default plugin;
