/// <reference types="react" />
export declare const List: ({ columns: userColumns, data, to, paginated, fetchData, loading, pageCount: controlledPageCount, dataSize, }: any) => JSX.Element;
export declare const PaginatedList: ({ url, columns, to, q }: any) => JSX.Element;
