export declare const NOTIFICATION_TYPES: {
    SUCCESS: string;
    DANGER: string;
    INFO: string;
    DEFAULT: string;
    WARNING: string;
};
export declare const sendNotification: ({ type, title, message, duration, }: any) => void;
