export declare const formatPlural: (count: number, text: string) => string;
export declare const formatSize: (sizeInBytes: number) => string;
export declare const copyToClipboard: (text: string, textType: string) => void;
