.channels-search {
  width: 100%;
  margin: 0 0 20px;
}

.list-row {
  display: flex;
  color: var(--jp-ui-font-color1);
  padding: 12px 20px;
  align-items: center;
  border-bottom: 1px solid var(--jp-layout-color2);
}

.list-row.clickable {
  cursor: pointer;
}

.list-row.clickable:hover {
  background-color: var(--jp-layout-color2);
}

.channel-list-description {
  margin: 5px 0 0;
  color: var(--jp-ui-font-color2);
  overflow: hidden;
  text-overflow: ellipsis;
  width: 100%;
}

.member-icon-column {
  width: 10%;
}
.member-name-column {
  width: 40%;
}
.member-username-column {
  width: 30%;
}
.member-role-column {
  width: 20%;
}
