<!doctype html><html><head><title>{{page_config['appName'] | e}}</title><link rel="apple-touch-icon" sizes="180x180" href="/icons/apple-touch-icon.png"><link rel="icon" type="image/png" sizes="32x32" href="/icons/favicon-32x32.png"><link rel="icon" type="image/png" sizes="16x16" href="/icons/favicon-16x16.png"><link rel="manifest" href="/site.webmanifest"><link rel="preconnect" href="https://fonts.gstatic.com"><link href="https://fonts.googleapis.com/css2?family=Open+Sans:wght@400;700&family=Source+Sans+Pro:wght@400;700&display=swap" rel="stylesheet"><script defer="defer" src="{{page_config.fullStaticUrl}}/main.05e349571da0c95daa65.js?v=05e349571da0c95daa65"></script><script defer="defer" src="{{page_config.fullStaticUrl}}/5047.b95e61d76607ffaee06d.js?v=b95e61d76607ffaee06d"></script><script defer="defer" src="{{page_config.fullStaticUrl}}/regenerator.f55891a524a621645d53.js?v=f55891a524a621645d53"></script></head><body>{# Copy so we do not modify the page_config with updates. #} {% set page_config_full = page_config.copy() %}<script id="jupyter-config-data" type="application/json">{{ page_config | tojson }}</script><script>/* Remove token from URL. */
    (function () {
      var parsedUrl = new URL(window.location.href);
      if (parsedUrl.searchParams.get('token')) {
        parsedUrl.searchParams.delete('token');
        window.history.replaceState({ }, '', parsedUrl.href);
      }
    })();</script></body></html>