import { paths } from './paths';
import { router } from './router';
import { theme } from './theme';
import { translator } from './translator';
export default [paths, router, theme, translator];
//# sourceMappingURL=index.js.map