export enum API_STATUSES {
  PENDING = 'PENDING',
  SUCCESS = 'SUCCESS',
  FAILED = 'FAILED',
}

export const KB_SIZE = 1024;
export const MB_SIZE = 1024 * KB_SIZE;
export const GB_SIZE = 1024 * MB_SIZE;
