import { LabIcon } from '@jupyterlab/ui-components';
/**
 * An anonymous avatar icon
 */
export declare const avatarIcon: LabIcon;
export declare const hamburgerIcon: LabIcon;
/**
 * Quetz logo
 */
export declare const quetzIcon: LabIcon;
