(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[4406],{34406:e=>{var t=e.exports={};var n;var r;function i(){throw new Error("setTimeout has not been defined")}function o(){throw new Error("clearTimeout has not been defined")}(function(){try{if(typeof setTimeout==="function"){n=setTimeout}else{n=i}}catch(e){n=i}try{if(typeof clearTimeout==="function"){r=clearTimeout}else{r=o}}catch(e){r=o}})();function u(e){if(n===setTimeout){return setTimeout(e,0)}if((n===i||!n)&&setTimeout){n=setTimeout;return setTimeout(e,0)}try{return n(e,0)}catch(t){try{return n.call(null,e,0)}catch(t){return n.call(this,e,0)}}}function c(e){if(r===clearTimeout){return clearTimeout(e)}if((r===o||!r)&&clearTimeout){r=clearTimeout;return clearTimeout(e)}try{return r(e)}catch(t){try{return r.call(null,e)}catch(t){return r.call(this,e)}}}var a=[];var s=false;var f;var l=-1;function h(){if(!s||!f){return}s=false;if(f.length){a=f.concat(a)}else{l=-1}if(a.length){p()}}function p(){if(s){return}var e=u(h);s=true;var t=a.length;while(t){f=a;a=[];while(++l<t){if(f){f[l].run()}}l=-1;t=a.length}f=null;s=false;c(e)}t.nextTick=function(e){var t=new Array(arguments.length-1);if(arguments.length>1){for(var n=1;n<arguments.length;n++){t[n-1]=arguments[n]}}a.push(new m(e,t));if(a.length===1&&!s){u(p)}};function m(e,t){this.fun=e;this.array=t}m.prototype.run=function(){this.fun.apply(null,this.array)};t.title="browser";t.browser=true;t.env={};t.argv=[];t.version="";t.versions={};function d(){}t.on=d;t.addListener=d;t.once=d;t.off=d;t.removeListener=d;t.removeAllListeners=d;t.emit=d;t.prependListener=d;t.prependOnceListener=d;t.listeners=function(e){return[]};t.binding=function(e){throw new Error("process.binding is not supported")};t.cwd=function(){return"/"};t.chdir=function(e){throw new Error("process.chdir is not supported")};t.umask=function(){return 0}}}]);