"use strict";(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[7353],{17353:(e,t,n)=>{n.r(t);n.d(t,{default:()=>v});var a=n(85168);const r={id:"@quetz-frontend/application-extension:paths",autoStart:true,provides:a.JupyterFrontEnd.IPaths,activate:e=>e.paths};const o={id:"@quetz-frontend/application-extension:router",autoStart:true,provides:a.IRouter,activate:e=>{const{commands:t}=e;const n=new a.Router({base:"/",commands:t});void e.started.then((()=>{void n.route();window.addEventListener("popstate",(()=>{void n.route()}))}));return n}};var s=n(79450);var i=n(18470);var u=n(70027);var d=n(61389);var c;(function(e){e.changeTheme="apputils:change-theme"})(c||(c={}));const p={id:"@quetz-frontend/application-extension:theme",autoStart:true,requires:[s.IThemeManager,u.IMenu],activate:(e,t,n)=>{const{commands:a}=e;e.started.then((()=>{if(t.themes.length>1){const e=new d.Menu({commands:a,renderer:i.MenuSvg.defaultRenderer});e.title.label="Theme";n.addItem({type:"submenu",submenu:e,rank:502});t.themes.forEach((t=>{e.addItem({command:c.changeTheme,args:{isPalette:false,theme:t}})}))}}))}};var m=n(86682);const h={id:"@quetz-frontend/application-extension:translator",autoStart:true,provides:m.ITranslator,activate:e=>{const t=new m.TranslationManager;return t}};const v=[r,o,p,h]}}]);