/* This is a generated file of CSS imports */
/* It was generated by @jupyterlab/builder in Build.ensureAssets() */

import '@quetz-frontend/application-extension/style/index.js';
import '@quetz-frontend/channels-extension/style/index.js';
import '@quetz-frontend/home-extension/style/index.js';
import '@quetz-frontend/jobs-extension/style/index.js';
import '@quetz-frontend/login-extension/style/index.js';
import '@quetz-frontend/menu-extension/style/index.js';
import '@quetz-frontend/search-extension/style/index.js';
import '@quetz-frontend/user-extension/style/index.js';
