import * as React from 'react';
import 'regenerator-runtime/runtime';
interface ITableFcProps {
    columns: any;
    data: any;
    renderRowSubComponent?: any;
}
declare const Table: React.FC<ITableFcProps>;
export default Table;
