/// <reference types="react" />
export declare const Pagination: ({ pageSize, pageCount, gotoPage, canPreviousPage, previousPage, nextPage, canNextPage, pageIndex, pageOptions, setPageSize, loading, }: any) => JSX.Element;
