import * as React from 'react';
declare class UserPackages extends React.PureComponent<any, any> {
    render(): JSX.Element;
}
export default UserPackages;
export declare const getUserChannelsTableColumns: () => any;
