/*-----------------------------------------------------------------------------
| Copyright (c) Jupyter Development Team.
| Distributed under the terms of the Modified BSD License.
|----------------------------------------------------------------------------*/
import '@quetz-frontend/application/style/index.js';
import '@quetz-frontend/apputils/style/index.js';
import '@quetz-frontend/table/style/index.js';
