export var API_STATUSES;
(function (API_STATUSES) {
    API_STATUSES["PENDING"] = "PENDING";
    API_STATUSES["SUCCESS"] = "SUCCESS";
    API_STATUSES["FAILED"] = "FAILED";
})(API_STATUSES || (API_STATUSES = {}));
export const KB_SIZE = 1024;
export const MB_SIZE = 1024 * KB_SIZE;
export const GB_SIZE = 1024 * MB_SIZE;
//# sourceMappingURL=constants.js.map