import { ITranslator } from '@jupyterlab/translation';
import { QuetzFrontEndPlugin } from '@quetz-frontend/application';
/**
 * A simplified Translator
 */
export declare const translator: QuetzFrontEndPlugin<ITranslator>;
