declare const _default: (import("@quetz-frontend/application").QuetzFrontEndPlugin<import("@jupyterlab/application").JupyterFrontEnd.IPaths> | import("@quetz-frontend/application").QuetzFrontEndPlugin<import("@jupyterlab/application").IRouter> | import("@quetz-frontend/application").QuetzFrontEndPlugin<void> | import("@quetz-frontend/application").QuetzFrontEndPlugin<import("@jupyterlab/translation").ITranslator>)[];
export default _default;
