export declare enum API_STATUSES {
    PENDING = "PENDING",
    SUCCESS = "SUCCESS",
    FAILED = "FAILED"
}
export declare const KB_SIZE = 1024;
export declare const MB_SIZE: number;
export declare const GB_SIZE: number;
