"use strict";(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[4648],{34648:(a,n,e)=>{e.r(n);e.d(n,{default:()=>u});var r=6e4;var t=r*60;var f=t*24;var i=f*365;var o=f*30;function u(a,n){n=n||{};var e=new Date(a).getTime()-Date.now();var u=Math.abs(e);if(u<r)return"just now";var h={year:u/i,month:u%i/o,day:u%o/f,hour:u%f/t,minute:u%t/r};var s,v,p=[],_=n.max||r;for(s in h){if(p.length<_){v=Math.floor(h[s]);if(v||n.zero){p.push(v+" "+(v==1?s:s+"s"))}}}s=p.length;_=", ";if(s>1&&n.and){if(s==2)_=" ";p[--s]="and "+p[s]}v=p.join(_);if(n.suffix){v+=e<0?" ago":" from now"}return v}}}]);