"use strict";(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[9819],{89819:(e,t,a)=>{a.r(t);a.d(t,{default:()=>u});var n=a(79450);var s=a.n(n);const r={id:"quetz-theme",requires:[n.IThemeManager],autoStart:true,activate:(e,t)=>{const a="quetz-theme/index.css";t.register({name:"Quetz",isLight:false,load:()=>t.loadCSS(a),unload:()=>Promise.resolve()})}};const u=r}}]);