"use strict";(self["webpackChunk_quetz_frontend_main_app"]=self["webpackChunk_quetz_frontend_main_app"]||[]).push([[2671],{42671:(e,n,a)=>{a.r(n);a.d(n,{default:()=>r});var t=a(70027);var o=a.n(t);const i={id:"@quetz-frontend/login-extension:plugin",autoStart:true,requires:[t.IMenu],activate:(e,n)=>{const a={github_login_available:{provider:"GitHub",api:"github"},google_login_available:{provider:"Google",api:"google"},azuread_login_available:{provider:"AzureAD",api:"azuread"}};const t=document.getElementById("jupyter-config-data");if(t){let e=200;try{const o=JSON.parse(t.innerHTML);for(const t in a){if(o[t]){n.addItem({command:"@quetz-frontend/menu-extension:login",args:a[t],rank:e++})}}}catch(o){console.error(o.message);for(const t in a){n.addItem(Object.assign(Object.assign({},a[t]),{rank:e++}))}}}}};const r=i}}]);