import { JupyterFrontEnd } from '@jupyterlab/application';
import { QuetzFrontEndPlugin } from '@quetz-frontend/application';
/**
 * The default paths.
 */
export declare const paths: QuetzFrontEndPlugin<JupyterFrontEnd.IPaths>;
