import * as React from 'react';
declare class ChannelDetailsMembers extends React.PureComponent<any, any> {
    render(): JSX.Element;
}
export default ChannelDetailsMembers;
export declare const getMembersListColumns: () => any;
