.jp-Dialog {
  width: 100%;
  height: 100%;
  position: absolute;
  z-index: 10000;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  top: 0px;
  left: 0px;
  margin: 0;
  padding: 0;
  background: var(--jp-dialog-background);
}

.jp-Dialog-content {
  min-width: 400px;
  max-height: none;
  min-height: 200px;
  max-height: 1000px;
  background: var(--jp-layout-color1) 0% 0% no-repeat padding-box;
  border-radius: 6px;
  opacity: 1;
}

.jp-Dialog-body {
  background-color: var(--jp-layout-color1);
  overflow-y: auto;
}

.jp-Dialog-header {
  text-align: left;
  font-size: var(--jp-ui-font-size2);
  letter-spacing: 0px;
  color: #ffffff;
  opacity: 1;
}

.qs-Form-Section {
  display: flex;
  flex-direction: column;
  margin-bottom: 10px;
}

.qs-Form-Section-Row {
  margin-bottom: 10px;
  border-bottom: 1px solid var(--jp-border-color1);
}

.qs-Form-Section-Label {
  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-font-color1);
  opacity: 1;
}

.qs-Label-Caption {
  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-brand-color1);
  opacity: 1;
}

/**********************
        Inputs
**********************/

label.qs-Input-Label {
  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-font-color1);
  opacity: 1;
}

label.qs-Input-Label:focus {
  outline: 0;
}

input.jp-mod-styled {
  border-radius: var(--jp-border-radius);
  opacity: 1;

  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-font-color1);
}

input.jp-mod-styled:focus {
  outline: 0;
}

select.jp-mod-styled {
  border-radius: var(--jp-border-radius);
  opacity: 1;

  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-font-color1);
}

select.jp-mod-styled:focus {
  outline: 0;
}

/**********************
        Buttons
**********************/

.bp3-button-text {
  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-border-color1);
  opacity: 1;
}

.jp-Button.minimal {
  border-radius: var(--jp-border-radius);
  opacity: 1;

  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-border-color1);
}

.jp-Button.minimal:focus {
  outline: 0;
}

button.jp-mod-styled {
  border: none !important;
}

button.jp-mod-styled.jp-mod-accept {
  background: var(--jp-brand-color1) 0% 0% no-repeat padding-box;
  border-radius: var(--jp-border-radius);
  opacity: 1;

  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-inverse-font-color1);
}

button.jp-mod-styled.jp-mod-accept:hover {
  background: var(--jp-brand-color0) 0% 0% no-repeat padding-box;
  color: var(--jp-ui-inverse-font-color0);
}

button.jp-mod-styled.jp-mod-accept:focus {
  outline: 1px solid var(--jp-brand-color1) !important;
}

button.jp-mod-styled.jp-mod-reject {
  background: var(--jp-inverse-layout-color2) 0% 0% no-repeat padding-box;
  border-radius: var(--jp-border-radius);
  opacity: 1;

  text-align: left;
  letter-spacing: 0px;
  color: var(--jp-ui-inverse-font-color2);
}

button.jp-mod-styled.jp-mod-reject:hover {
  background: var(--jp-inverse-layout-color3) 0% 0% no-repeat padding-box;
  color: var(--jp-ui-inverse-font-color3);
}
