import { QuetzFrontEndPlugin } from '@quetz-frontend/application';
/**
 * The command ids used by the main plugin.
 */
export declare namespace CommandIDs {
    const open = "@quetz-frontend/search-extension:open";
}
/**
 * The main menu plugin.
 */
declare const plugin: QuetzFrontEndPlugin<void>;
export default plugin;
