import '@quetz-frontend/about-extension';
import '@quetz-frontend/application';
import '@quetz-frontend/application-extension';
import '@quetz-frontend/apputils';
import '@quetz-frontend/channels-extension';
import '@quetz-frontend/home-extension';
import '@quetz-frontend/jobs-extension';
import '@quetz-frontend/login-extension';
import '@quetz-frontend/menu';
import '@quetz-frontend/menu-extension';
import '@quetz-frontend/search-extension';
import '@quetz-frontend/table';
import '@quetz-frontend/user-extension';
//# sourceMappingURL=index.js.map