import * as React from 'react';
declare class PackageMainContent extends React.PureComponent<any, any> {
    private _formatPlatform;
    render(): JSX.Element;
}
declare const _default: React.ComponentClass<Pick<any, string | number | symbol> & {
    wrappedComponentRef?: ((instance: PackageMainContent | null) => void) | React.RefObject<PackageMainContent> | null | undefined;
}, any> & import("react-router").WithRouterStatics<typeof PackageMainContent>;
export default _default;
